import React from 'react';
import { hot } from 'react-hot-loader';
import './App.scss';
import { QandaPool } from '../lib';
import * as api from './api';

class App extends React.Component {
    state = {
        userUid: 'a981a50c-bc92-4d59-bcde-659ace31b093',
        orderId: '2140',
        orderUid: '15ee744b-86e8-47ab-a700-fd7ce34631ba',
        list: [],
        isAddingQuestion: false,
        groupKey: 'groupKey',
        error: ''
    }

    render() {
        const { userUid, orderId, orderUid, list, groupKey, isAddingQuestion, error } = this.state;

        return (
            <div className="col col-12 col-lg-12 d-flex flex-column h-100">
                <div className="container-fluid">
                    <p className="h3">LD qanda - Order question</p>
                </div>
                <div className="question-zone d-flex flex-fill mb-3">
                    <div className="shadow bg-white rounded text-primary h-100 w-100">
                        <QandaPool
                            userUid={userUid}
                            orderId={orderId}
                            orderUid={orderUid}

                            isAddingQuestion={isAddingQuestion}
                            list={list}
                            groupKey={groupKey}
                            error={error}

                            onSearchText={this.searchText}
                            onSaveQuestion={this.handleSaveQuestion}
                            onResolveQuestion={this.handleResolveQuestion}
                            onSaveAnswer={this.handleSaveAnswer}
                            onNewQuestion={this.handleNewQuestion}
                            onCancelQuestion={this.handleCancelQuestion}
                        />
                    </div>
                </div>
            </div>
        )
    }

    async componentDidMount() {
        const res = await api.activeQuestions(this.state.orderId);
        this.setState({
            list: res.data
        })
    }

    searchText = async (keyword, orderUid) => {
        const result = await api.searchText(keyword, orderUid);
        const { total, sources } = result.data || {};
        const options = total
            ? sources.map(ctx => ({ value: ctx.id, label: ctx.sourceText, ctx }))
            : [];
        return options;
    }

    handleSaveQuestion = question => {
        const list = this.state.list;
        return api.saveQuestion(question)
            .then(res => {
                list.unshift(res.data);
                this.setState({
                    list,
                    isAddingQuestion: false
                });
            })
            .catch(async err => {
                this.setState({ isAddingQuestion: false, error: JSON.stringify(await err, null,2) });
            });
    };

    handleResolveQuestion = async question => {
        const isResolved = question.state == '8';
        const res = await api.resolveQuestion(question.id, !isResolved);
        const list = this.state.list.map(q => q.id === res.data.id ? res.data : q);
        this.setState({ list });
        return res;
    }

    handleSaveAnswer = async ({ id, content }) => {
        const { data: answer } = await api.saveAnswer({ questionId: id, content });

        const list = this.state.list.reduce((res, q) => {
            if (q.id === answer.questionId) q.answers.push(answer);
            res.push(q);
            return res;
        }, []);

        this.setState({ list });

        return answer;
    };

    handleNewQuestion = () => {
        this.setState({ isAddingQuestion: true });
    }

    handleCancelQuestion = () => {
        this.setState({ isAddingQuestion: false });
    }
}

export default hot(module)(App)
