import React from 'react';
import { string, array, func, bool } from 'prop-types';
import * as helper from './help';

const QandaContext = React.createContext({
    userUid: null,
    orderUid: null,
    orderId: null,
    onSearchText: () => {},
    onSaveQuestion: () => {},
    onSaveAnswer: () => {},
    onNewQuestion: () => {},
    onCancelQuestion: () => {},
    authorName: () => {}
});


export const WithQandaContextProvider = Component => {
    class WrapperQandaContextProvider extends React.PureComponent{
        static propTypes = {
            userUid: string.isRequired,
            orderId: string.isRequired,
            orderUid: string.isRequired,

            list: array.isRequired,
            groupKey: string.isRequired,
            isAddingQuestion: bool.isRequired,
            error: string,

            onSearchText: func.isRequired,
            onSaveQuestion: func.isRequired,
            onResolveQuestion: func.isRequired,
            onSaveAnswer: func.isRequired,
            onNewQuestion: func.isRequired,
            onCancelQuestion: func.isRequired
        }

        constructor(props){
            super(props);
            const {userUid, orderUid, orderId, onCancelQuestion, onNewQuestion, onSaveAnswer, onSaveQuestion, onResolveQuestion} = this.props;
            this.state={
                context:{
                    userUid,
                    orderId,
                    orderUid,
                    onSaveAnswer,
                    onSaveQuestion,
                    onNewQuestion,
                    onCancelQuestion,
                    onResolveQuestion,
                    onSearchText: this.onSearchText,
                    authorName: this.authorName
                }
            }
        }

        render(){
            const {context} = this.state;
            return(
                <QandaContext.Provider value={context}>
                    <Component {...this.props} />
                </QandaContext.Provider>
            )
        }
        authorName = (members, authorId) => {
            return helper.authorName(members, authorId, this.props.userUid);
        }
        onSearchText = keywords => this.props.onSearchText(keywords, this.props.orderUid)
        
    }
    return WrapperQandaContextProvider;
}

export const ConsumQandaContext = Component => {
    return function WrapperConsumer(props) {
        return (
            <QandaContext.Consumer>
                {context => (<Component {...props} {...context} />)}
            </QandaContext.Consumer>
        )
    };
}

export default QandaContext;
