import React from 'react';
import { string, object, any, func } from 'prop-types';
import { buildHighlightMatchedText } from './utils';
import QuestionThread from './QuestionThread';

export default class QuestionGroup extends React.PureComponent {
    static propTypes = {
        selectedThread: string,
        style: object.isRequired,
        data: any,
        markText: string,
        onThreadSelect: func,
        measure: func.isRequired
    }

    componentDidUpdate(preProps, preState){
       if(preProps.data!==this.props.data){
            this.props.measure();
       } 
    }

    render() {
        const { data, markText, selectedThread, onThreadSelect, measure } = this.props;
        const [ctx, dataList] = data;
        const { stringKey, sourceText } = ctx || {};
        const sourceTitle = sourceText ? 'Source text' : 'General';

        return (
            <div style={this.props.style} className="qanda-group">
                <div className="qanda-group-content">
                    <div className="qanda-group-header flex-column">
                        <p className="card-subtitle small">{sourceTitle}</p>
                        {sourceText && <p className="card-title">{buildHighlightMatchedText(sourceText, markText)}</p>}
                        {stringKey && <p className="small">{stringKey}</p>}
                    </div>

                    <div className="qanda-group-body">
                        {
                            dataList.map(thread =>
                                <QuestionThread
                                    key={thread.id}
                                    id={thread.id + ''}
                                    thread={thread}
                                    active={selectedThread + '' === thread.id + ''}
                                    onSelect={onThreadSelect}
                                    measure={measure}
                                />
                            )
                        }
                    </div>
                </div>
            </div>
        );
    }
}