import React from 'react';
import { string, array, bool } from 'prop-types';
import Immutable from 'immutable';
import QuestionList from './QuestionList';
import QandaNew from './QandaNew';
import Message from './Message';
import * as help from './help';
import { WithQandaContextProvider } from './QandaContext';

class QuestionPool extends React.PureComponent {
    static propTypes = {
        list: array.isRequired,
        groupKey: string.isRequired,
        isAddingQuestion: bool,
        error: string
    }

    constructor(props, context) {
        super(props, context);

        this.state = {
            list: null,
            listgroups: Immutable.List([])
        };
    }

    static getDerivedStateFromProps(props, state) {
        const { list, groupKey } = props;
        if (list || state.list !== list) {
            const groupMap = help.groupQuestionsBy(list, groupKey);
            const listgroups = help.listQuestionGroups(groupMap);
            return { list, listgroups };
        }
        return null;
    }

    render() {
        const { listgroups } = this.state;
        const { error, isAddingQuestion } = this.props;
        const message = error && (
            <Message type="danger" message={error} />
        );

        return (
            <div className="qanda d-flex flex-column h-100 w-100">
                <div className="qanda-header container mt-2">
                    <div className="row h4">
                        <div className="col col-1 col-1-md">
                            <i className="far fa-comments"></i>
                        </div>
                        <div className="col col-9 col-md-11">
                            <p className="h3 text-truncate">Q&amp;A</p>
                        </div>
                    </div>
                    {message}
                </div>
                {
                    isAddingQuestion
                        ? <QandaNew />
                        : <QuestionList listgroups={listgroups} />
                }
            </div>
        );
    }
}

export default WithQandaContextProvider(QuestionPool);
