const webpack = require('webpack');
const Dotenv = require('dotenv-webpack');

module.exports = {
  mode:'development',
  entry: [
    './src/example/index.jsx',
    'webpack-dev-server/client?http://localhost:3000',
    'webpack/hot/only-dev-server'
  ],
  module: {
    rules: [
      {
        test: /\.(js|jsx)$/,
        exclude: /node_modules/,
        use: ['babel-loader']
      },
      {
        test: /\.scss$/,
        use: [
            "style-loader",
            "css-loader",
            "sass-loader"
        ]
      }
    ]
  },
  resolve: {
    extensions: ['*', '.js', '.jsx']
  },
  output: {
    path: __dirname + '/dist',
    publicPath: '/static',
    filename: 'bundle.js'
  },
  plugins: [
    new webpack.HotModuleReplacementPlugin(),
    new Dotenv()
  ],
  devServer: {
    hot:true,
    open: true, 
    host: '0.0.0.0',
    port: 3000,
    public: 'localhost:3000',
    contentBase: './src/example/public',
    publicPath: '/static',
    historyApiFallback: true,
    proxy: {
      '/assets': {
          target: 'http://localhost:3000',
          pathRewrite: {'^/assets' : '/assets'}
       }
    }
  }
};
